/*
 * The contents of this file are subject to the terms
 * of the Common Development and Distribution License
 * (the License).  You may not use this file except in
 * compliance with the License.
 *
 * You can obtain a copy of the license at
 * https://glassfish.dev.java.net/public/CDDLv1.0.html or
 * glassfish/bootstrap/legal/CDDLv1.0.txt.
 * See the License for the specific language governing
 * permissions and limitations under the License.
 *
 * When distributing Covered Code, include this CDDL
 * Header Notice in each file and include the License file
 * at glassfish/bootstrap/legal/CDDLv1.0.txt.
 * If applicable, add the following below the CDDL Header,
 * with the fields enclosed by brackets [] replaced by
 * you own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 *
 * Copyright 2006 Sun Microsystems, Inc. All rights reserved.
 */

package com.sun.grizzly.connectioncache.server;

import com.sun.grizzly.DefaultSelectionKeyHandler;
import com.sun.grizzly.connectioncache.spi.transport.ConnectionCacheFactory;
import com.sun.grizzly.connectioncache.spi.transport.InboundConnectionCache;
import java.nio.channels.SelectableChannel;
import java.nio.channels.SelectionKey;


/**
 * Extended implementation of the DefaultSelectionKeyHandler with
 * ConnectionManagement integrated in it
 *
 * @author Alexey Stashok
 */
public class CacheableSelectionKeyHandler extends DefaultSelectionKeyHandler {
    private InboundConnectionCache<SelectableChannel> inboundConnectionCache;
    /**
     * Construct ConnectionManagementSelectionKeyHandler
     * @param highWaterMark max number of simultaneously open connections
     * @param numberToReclaim number of connections to reclaim
     */
    public CacheableSelectionKeyHandler(int highWaterMark, int numberToReclaim) {
        inboundConnectionCache = ConnectionCacheFactory.<SelectableChannel>makeBlockingInboundConnectionCache(
                "Grizzly inbound connection cache", highWaterMark,
                numberToReclaim, getLogger());
    }
    
    /**
     * @Override
     */
    public void process(SelectionKey key) {
        inboundConnectionCache.requestReceived(key.channel());
    }
    
    /**
     * @Override
     */
    public void postProcess(SelectionKey key) {
        SelectableChannel channel = key.channel();
        inboundConnectionCache.requestProcessed(channel, 1);
        inboundConnectionCache.responseSent(channel);
    }
    
    /**
     * @Override
     */
    public void cancel(SelectionKey key) {
        super.cancel(key);
        inboundConnectionCache.close(key.channel());
    }    
}
